summaryrefslogtreecommitdiffstats
path: root/generic/tclCompCmds.c
diff options
context:
space:
mode:
Diffstat (limited to 'generic/tclCompCmds.c')
-rw-r--r--generic/tclCompCmds.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/generic/tclCompCmds.c b/generic/tclCompCmds.c
index 395a0f8..4d015ec 100644
--- a/generic/tclCompCmds.c
+++ b/generic/tclCompCmds.c
@@ -1943,7 +1943,7 @@ TclCompileForeachCmd(
*
* TclCompileEachloopCmd --
*
* Procedure called to compile the "foreach" and "mapeach" commands.
*
* Results:
* Returns TCL_OK for a successful compile. Returns TCL_ERROR to defer
@@ -3832,23 +3832,23 @@ TclCompileLsetCmd(
/*
*----------------------------------------------------------------------
*
- * TclCompileMapeachCmd --
+ * TclCompileLmapCmd --
*
* Procedure called to compile the "mapeach" command.
*
* Results:
* Returns TCL_OK for a successful compile. Returns TCL_ERROR to defer
* evaluation to runtime.
*
* Side effects:
* Instructions are added to envPtr to execute the "mapeach" command at
* runtime.
*
*----------------------------------------------------------------------
*/
int
-TclCompileMapeachCmd(
+TclCompileLmapCmd(
Tcl_Interp *interp, /* Used for error reporting. */
Tcl_Parse *parsePtr, /* Points to a parse structure for the command
* created by Tcl_ParseCommand. */
@@ -1943,7 +1943,7 @@ TclCompileForeachCmd(
* TclCompileEachloopCmd --
*
- * Procedure called to compile the "foreach" and "mapeach" commands.
+ * Procedure called to compile the "foreach" and "lmap" commands.
*
* Results:
@@ -3832,23 +3832,23 @@ TclCompileLsetCmd(
*
- * Procedure called to compile the "mapeach" command.
+ * Procedure called to compile the "lmap" command.
*
* Results:
@@ -3832,23 +3832,23 @@ TclCompileLsetCmd(
*
* Side effects:
- * Instructions are added to envPtr to execute the "mapeach" command at
+ * Instructions are added to envPtr to execute the "lmap" command at
* runtime.
*